==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/HandleCookiesRequest.hpp <==
#ifndef _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HPP_
#define _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HDL_
#include "com/sun/star/ucb/HandleCookiesRequest.hdl"
#endif

#ifndef _COM_SUN_STAR_UCB_COOKIE_HPP_
#include "com/sun/star/ucb/Cookie.hpp"
#endif
#ifndef _COM_SUN_STAR_TASK_CLASSIFIEDINTERACTIONREQUEST_HPP_
#include "com/sun/star/task/ClassifiedInteractionRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_COOKIEREQUEST_HPP_
#include "com/sun/star/ucb/CookieRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline HandleCookiesRequest::HandleCookiesRequest() SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest()
    , URL()
    , Cookies()
    , Request(::com::sun::star::ucb::CookieRequest_RECEIVE)
{ }

inline HandleCookiesRequest::HandleCookiesRequest(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::task::InteractionClassification& Classification_, const ::rtl::OUString& URL_, const ::com::sun::star::uno::Sequence< ::com::sun::star::ucb::Cookie >& Cookies_, const ::com::sun::star::ucb::CookieRequest& Request_) SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest(Message_, Context_, Classification_)
    , URL(URL_)
    , Cookies(Cookies_)
    , Request(Request_)
{ }

HandleCookiesRequest::HandleCookiesRequest(HandleCookiesRequest const & the_other): ::com::sun::star::task::ClassifiedInteractionRequest(the_other), URL(the_other.URL), Cookies(the_other.Cookies), Request(the_other.Request) {}

HandleCookiesRequest::~HandleCookiesRequest() {}

HandleCookiesRequest & HandleCookiesRequest::operator =(HandleCookiesRequest const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::task::ClassifiedInteractionRequest::operator =(the_other);
    URL = the_other.URL;
    Cookies = the_other.Cookies;
    Request = the_other.Request;
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::ucb::HandleCookiesRequest* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.HandleCookiesRequest" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/HandleCookiesRequest.hpp <==
#ifndef _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HPP_
#define _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HDL_
#include "com/sun/star/ucb/HandleCookiesRequest.hdl"
#endif

#ifndef _COM_SUN_STAR_UCB_COOKIE_HPP_
#include "com/sun/star/ucb/Cookie.hpp"
#endif
#ifndef _COM_SUN_STAR_TASK_CLASSIFIEDINTERACTIONREQUEST_HPP_
#include "com/sun/star/task/ClassifiedInteractionRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_COOKIEREQUEST_HPP_
#include "com/sun/star/ucb/CookieRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline HandleCookiesRequest::HandleCookiesRequest() SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest()
    , URL()
    , Cookies()
    , Request(::com::sun::star::ucb::CookieRequest_RECEIVE)
{ }

inline HandleCookiesRequest::HandleCookiesRequest(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::task::InteractionClassification& Classification_, const ::rtl::OUString& URL_, const ::com::sun::star::uno::Sequence< ::com::sun::star::ucb::Cookie >& Cookies_, const ::com::sun::star::ucb::CookieRequest& Request_) SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest(Message_, Context_, Classification_)
    , URL(URL_)
    , Cookies(Cookies_)
    , Request(Request_)
{ }

HandleCookiesRequest::HandleCookiesRequest(HandleCookiesRequest const & the_other): ::com::sun::star::task::ClassifiedInteractionRequest(the_other), URL(the_other.URL), Cookies(the_other.Cookies), Request(the_other.Request) {}

HandleCookiesRequest::~HandleCookiesRequest() {}

HandleCookiesRequest & HandleCookiesRequest::operator =(HandleCookiesRequest const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::task::ClassifiedInteractionRequest::operator =(the_other);
    URL = the_other.URL;
    Cookies = the_other.Cookies;
    Request = the_other.Request;
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace ucb {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::ucb::HandleCookiesRequest const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.HandleCookiesRequest" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::ucb::HandleCookiesRequest const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::ucb::HandleCookiesRequest >::get();
}

#endif // _COM_SUN_STAR_UCB_HANDLECOOKIESREQUEST_HPP_
